@@ -1,5 +1,3 @@
-from __future__ import unicode_literals, absolute_import
-
 import io
 import os
 import re
@@ -7,6 +5,8 @@ import abc
 import csv
 import sys
 import zipp
+import email
+import pathlib
 import operator
 import functools
 import itertools
@@ -14,30 +14,18 @@ import posixpath
 import collections
 
 from ._compat import (
-    install,
     NullFinder,
-    ConfigParser,
-    suppress,
-    map,
-    FileNotFoundError,
-    IsADirectoryError,
-    NotADirectoryError,
-    PermissionError,
-    pathlib,
-    ModuleNotFoundError,
-    MetaPathFinder,
-    email_message_from_string,
     PyPy_repr,
-    unique_ordered,
-    str,
+    install,
     )
+
+from configparser import ConfigParser
+from contextlib import suppress
 from importlib import import_module
+from importlib.abc import MetaPathFinder
 from itertools import starmap
 
 
-__metaclass__ = type
-
-
 __all__ = [
     'Distribution',
     'DistributionFinder',
@@ -77,8 +65,8 @@ class EntryPoint(
 
     pattern = re.compile(
         r'(?P<module>[\w.]+)\s*'
-        r'(:\s*(?P<attr>[\w.]+)\s*)?'
-        r'((?P<extras>\[.*\])\s*)?$'
+        r'(:\s*(?P<attr>[\w.]+))?\s*'
+        r'(?P<extras>\[.*\])?\s*$'
         )
     """
     A regular expression describing the syntax for an entry point,
@@ -277,7 +265,7 @@ class Distribution:
             # (which points to the egg-info file) attribute unchanged.
             or self.read_text('')
             )
-        return email_message_from_string(text)
+        return email.message_from_string(text)
 
     @property
     def version(self):
@@ -447,7 +435,7 @@ class FastPath:
 
     def children(self):
         with suppress(Exception):
-            return os.listdir(self.root or '.')
+            return os.listdir(self.root or '')
         with suppress(Exception):
             return self.zip_children()
         return []
@@ -457,72 +445,48 @@ class FastPath:
         names = zip_path.root.namelist()
         self.joinpath = zip_path.joinpath
 
-        return unique_ordered(
+        return dict.fromkeys(
             child.split(posixpath.sep, 1)[0]
             for child in names
             )
 
-    def search(self, name):
+    def is_egg(self, search):
+        base = self.base
         return (
-            self.joinpath(child)
-            for child in self.children()
-            if name.matches(child, self.base)
-            )
+            base == search.versionless_egg_name
+            or base.startswith(search.prefix)
+            and base.endswith('.egg'))
+
+    def search(self, name):
+        for child in self.children():
+            n_low = child.lower()
+            if (n_low in name.exact_matches
+                    or n_low.startswith(name.prefix)
+                    and n_low.endswith(name.suffixes)
+                    # legacy case:
+                    or self.is_egg(name) and n_low == 'egg-info'):
+                yield self.joinpath(child)
 
 
 class Prepared:
     """
     A prepared search for metadata on a possibly-named package.
     """
-    normalized = None
+    normalized = ''
+    prefix = ''
     suffixes = '.dist-info', '.egg-info'
     exact_matches = [''][:0]
+    versionless_egg_name = ''
 
     def __init__(self, name):
         self.name = name
         if name is None:
             return
-        self.normalized = self.normalize(name)
+        self.normalized = name.lower().replace('-', '_')
+        self.prefix = self.normalized + '-'
         self.exact_matches = [
             self.normalized + suffix for suffix in self.suffixes]
-
-    @staticmethod
-    def normalize(name):
-        """
-        PEP 503 normalization plus dashes as underscores.
-        """
-        return re.sub(r"[-_.]+", "-", name).lower().replace('-', '_')
-
-    @staticmethod
-    def legacy_normalize(name):
-        """
-        Normalize the package name as found in the convention in
-        older packaging tools versions and specs.
-        """
-        return name.lower().replace('-', '_')
-
-    def matches(self, cand, base):
-        low = cand.lower()
-        pre, ext = os.path.splitext(low)
-        name, sep, rest = pre.partition('-')
-        return (
-            low in self.exact_matches
-            or ext in self.suffixes and (
-                not self.normalized or
-                name.replace('.', '_') == self.normalized
-                )
-            # legacy case:
-            or self.is_egg(base) and low == 'egg-info'
-            )
-
-    def is_egg(self, base):
-        normalized = self.legacy_normalize(self.name or '')
-        prefix = normalized + '-' if normalized else ''
-        versionless_egg_name = normalized + '.egg' if self.name else ''
-        return (
-            base == versionless_egg_name
-            or base.startswith(prefix)
-            and base.endswith('.egg'))
+        self.versionless_egg_name = self.normalized + '.egg'
 
 
 @install
