@@ -1,18 +1,13 @@
-from __future__ import unicode_literals
-
 import os
 import sys
 import shutil
+import pathlib
 import tempfile
 import textwrap
+import contextlib
 
 from .py39compat import FS_NONASCII
 
-from importlib_metadata._compat import pathlib, contextlib
-
-
-__metaclass__ = type
-
 
 @contextlib.contextmanager
 def tempdir():
@@ -104,42 +99,6 @@ class DistInfoPkg(OnSysPath, SiteDir):
         build_files(DistInfoPkg.files, self.site_dir)
 
 
-class DistInfoPkgWithDot(OnSysPath, SiteDir):
-    files = {
-        "pkg_dot-1.0.0.dist-info": {
-            "METADATA": """
-                Name: pkg.dot
-                Version: 1.0.0
-                """,
-            },
-        }
-
-    def setUp(self):
-        super(DistInfoPkgWithDot, self).setUp()
-        build_files(DistInfoPkgWithDot.files, self.site_dir)
-
-
-class DistInfoPkgWithDotLegacy(OnSysPath, SiteDir):
-    files = {
-        "pkg.dot-1.0.0.dist-info": {
-            "METADATA": """
-                Name: pkg.dot
-                Version: 1.0.0
-                """,
-            },
-        "pkg.lot.egg-info": {
-            "METADATA": """
-                Name: pkg.lot
-                Version: 1.0.0
-                """,
-            },
-        }
-
-    def setUp(self):
-        super(DistInfoPkgWithDotLegacy, self).setUp()
-        build_files(DistInfoPkgWithDotLegacy.files, self.site_dir)
-
-
 class DistInfoPkgOffPath(SiteDir):
     def setUp(self):
         super(DistInfoPkgOffPath, self).setUp()
