@@ -1,10 +1,6 @@
 import re
 import textwrap
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 from . import fixtures
 from importlib_metadata import (
@@ -12,21 +8,10 @@ from importlib_metadata import (
     entry_points, files, metadata, requires, version,
     )
 
-try:
-    from collections.abc import Iterator
-except ImportError:
-    from collections import Iterator  # noqa: F401
-
-try:
-    from builtins import str as text
-except ImportError:
-    from __builtin__ import unicode as text
-
 
 class APITests(
         fixtures.EggInfoPkg,
         fixtures.DistInfoPkg,
-        fixtures.DistInfoPkgWithDot,
         fixtures.EggInfoFile,
         unittest.TestCase):
 
@@ -34,31 +19,18 @@ class APITests(
 
     def test_retrieves_version_of_self(self):
         pkg_version = version('egginfo-pkg')
-        assert isinstance(pkg_version, text)
+        assert isinstance(pkg_version, str)
         assert re.match(self.version_pattern, pkg_version)
 
     def test_retrieves_version_of_distinfo_pkg(self):
         pkg_version = version('distinfo-pkg')
-        assert isinstance(pkg_version, text)
+        assert isinstance(pkg_version, str)
         assert re.match(self.version_pattern, pkg_version)
 
     def test_for_name_does_not_exist(self):
         with self.assertRaises(PackageNotFoundError):
             distribution('does-not-exist')
 
-    def test_name_normalization(self):
-        names = 'pkg.dot', 'pkg_dot', 'pkg-dot', 'pkg..dot', 'Pkg.Dot'
-        for name in names:
-            with self.subTest(name):
-                assert distribution(name).metadata['Name'] == 'pkg.dot'
-
-    def test_prefix_not_matched(self):
-        prefixes = 'p', 'pkg', 'pkg.'
-        for prefix in prefixes:
-            with self.subTest(prefix):
-                with self.assertRaises(PackageNotFoundError):
-                    distribution(prefix)
-
     def test_for_top_level(self):
         self.assertEqual(
             distribution('egginfo-pkg').read_text('top_level.txt').strip(),
@@ -174,20 +146,6 @@ class APITests(
         assert deps == expected
 
 
-class LegacyDots(fixtures.DistInfoPkgWithDotLegacy, unittest.TestCase):
-    def test_name_normalization(self):
-        names = 'pkg.dot', 'pkg_dot', 'pkg-dot', 'pkg..dot', 'Pkg.Dot'
-        for name in names:
-            with self.subTest(name):
-                assert distribution(name).metadata['Name'] == 'pkg.dot'
-
-    def test_name_normalization_versionless_egg_info(self):
-        names = 'pkg.lot', 'pkg_lot', 'pkg-lot', 'pkg..lot', 'Pkg.Lot'
-        for name in names:
-            with self.subTest(name):
-                assert distribution(name).metadata['Name'] == 'pkg.lot'
-
-
 class OffSysPathTests(fixtures.DistInfoPkgOffPath, unittest.TestCase):
     def test_find_distributions_specified_path(self):
         dists = Distribution.discover(path=[str(self.site_dir)])
